from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_auto_blacklist import ServerConfigAutoBlacklist
    from peertube.models.server_config_avatar import ServerConfigAvatar
    from peertube.models.server_config_contact_form import ServerConfigContactForm
    from peertube.models.server_config_email import ServerConfigEmail
    from peertube.models.server_config_export import ServerConfigExport
    from peertube.models.server_config_federation import ServerConfigFederation
    from peertube.models.server_config_followings import ServerConfigFollowings
    from peertube.models.server_config_homepage import ServerConfigHomepage
    from peertube.models.server_config_import import ServerConfigImport
    from peertube.models.server_config_instance import ServerConfigInstance
    from peertube.models.server_config_open_telemetry import ServerConfigOpenTelemetry
    from peertube.models.server_config_plugin import ServerConfigPlugin
    from peertube.models.server_config_search import ServerConfigSearch
    from peertube.models.server_config_signup import ServerConfigSignup
    from peertube.models.server_config_theme import ServerConfigTheme
    from peertube.models.server_config_tracker import ServerConfigTracker
    from peertube.models.server_config_transcoding import ServerConfigTranscoding
    from peertube.models.server_config_trending import ServerConfigTrending
    from peertube.models.server_config_user import ServerConfigUser
    from peertube.models.server_config_video import ServerConfigVideo
    from peertube.models.server_config_video_caption import ServerConfigVideoCaption
    from peertube.models.server_config_views import ServerConfigViews


T = TypeVar("T", bound="ServerConfig")


@_attrs_define
class ServerConfig:
    """Attributes:
    instance (Union[Unset, ServerConfigInstance]):
    search (Union[Unset, ServerConfigSearch]):
    plugin (Union[Unset, ServerConfigPlugin]):
    theme (Union[Unset, ServerConfigTheme]):
    email (Union[Unset, ServerConfigEmail]):
    contact_form (Union[Unset, ServerConfigContactForm]):
    server_version (Union[Unset, str]):
    server_commit (Union[Unset, str]):
    signup (Union[Unset, ServerConfigSignup]):
    transcoding (Union[Unset, ServerConfigTranscoding]):
    import_ (Union[Unset, ServerConfigImport]):
    export (Union[Unset, ServerConfigExport]):
    auto_blacklist (Union[Unset, ServerConfigAutoBlacklist]):
    avatar (Union[Unset, ServerConfigAvatar]):
    video (Union[Unset, ServerConfigVideo]):
    video_caption (Union[Unset, ServerConfigVideoCaption]):
    user (Union[Unset, ServerConfigUser]):
    trending (Union[Unset, ServerConfigTrending]):
    tracker (Union[Unset, ServerConfigTracker]):
    followings (Union[Unset, ServerConfigFollowings]):
    federation (Union[Unset, ServerConfigFederation]):
    homepage (Union[Unset, ServerConfigHomepage]):
    open_telemetry (Union[Unset, ServerConfigOpenTelemetry]): PeerTube >=6.1
    views (Union[Unset, ServerConfigViews]): PeerTube >=6.1
    """

    instance: Union[Unset, "ServerConfigInstance"] = UNSET
    search: Union[Unset, "ServerConfigSearch"] = UNSET
    plugin: Union[Unset, "ServerConfigPlugin"] = UNSET
    theme: Union[Unset, "ServerConfigTheme"] = UNSET
    email: Union[Unset, "ServerConfigEmail"] = UNSET
    contact_form: Union[Unset, "ServerConfigContactForm"] = UNSET
    server_version: Unset | str = UNSET
    server_commit: Unset | str = UNSET
    signup: Union[Unset, "ServerConfigSignup"] = UNSET
    transcoding: Union[Unset, "ServerConfigTranscoding"] = UNSET
    import_: Union[Unset, "ServerConfigImport"] = UNSET
    export: Union[Unset, "ServerConfigExport"] = UNSET
    auto_blacklist: Union[Unset, "ServerConfigAutoBlacklist"] = UNSET
    avatar: Union[Unset, "ServerConfigAvatar"] = UNSET
    video: Union[Unset, "ServerConfigVideo"] = UNSET
    video_caption: Union[Unset, "ServerConfigVideoCaption"] = UNSET
    user: Union[Unset, "ServerConfigUser"] = UNSET
    trending: Union[Unset, "ServerConfigTrending"] = UNSET
    tracker: Union[Unset, "ServerConfigTracker"] = UNSET
    followings: Union[Unset, "ServerConfigFollowings"] = UNSET
    federation: Union[Unset, "ServerConfigFederation"] = UNSET
    homepage: Union[Unset, "ServerConfigHomepage"] = UNSET
    open_telemetry: Union[Unset, "ServerConfigOpenTelemetry"] = UNSET
    views: Union[Unset, "ServerConfigViews"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        instance: Unset | dict[str, Any] = UNSET
        if not isinstance(self.instance, Unset):
            instance = self.instance.to_dict()

        search: Unset | dict[str, Any] = UNSET
        if not isinstance(self.search, Unset):
            search = self.search.to_dict()

        plugin: Unset | dict[str, Any] = UNSET
        if not isinstance(self.plugin, Unset):
            plugin = self.plugin.to_dict()

        theme: Unset | dict[str, Any] = UNSET
        if not isinstance(self.theme, Unset):
            theme = self.theme.to_dict()

        email: Unset | dict[str, Any] = UNSET
        if not isinstance(self.email, Unset):
            email = self.email.to_dict()

        contact_form: Unset | dict[str, Any] = UNSET
        if not isinstance(self.contact_form, Unset):
            contact_form = self.contact_form.to_dict()

        server_version = self.server_version

        server_commit = self.server_commit

        signup: Unset | dict[str, Any] = UNSET
        if not isinstance(self.signup, Unset):
            signup = self.signup.to_dict()

        transcoding: Unset | dict[str, Any] = UNSET
        if not isinstance(self.transcoding, Unset):
            transcoding = self.transcoding.to_dict()

        import_: Unset | dict[str, Any] = UNSET
        if not isinstance(self.import_, Unset):
            import_ = self.import_.to_dict()

        export: Unset | dict[str, Any] = UNSET
        if not isinstance(self.export, Unset):
            export = self.export.to_dict()

        auto_blacklist: Unset | dict[str, Any] = UNSET
        if not isinstance(self.auto_blacklist, Unset):
            auto_blacklist = self.auto_blacklist.to_dict()

        avatar: Unset | dict[str, Any] = UNSET
        if not isinstance(self.avatar, Unset):
            avatar = self.avatar.to_dict()

        video: Unset | dict[str, Any] = UNSET
        if not isinstance(self.video, Unset):
            video = self.video.to_dict()

        video_caption: Unset | dict[str, Any] = UNSET
        if not isinstance(self.video_caption, Unset):
            video_caption = self.video_caption.to_dict()

        user: Unset | dict[str, Any] = UNSET
        if not isinstance(self.user, Unset):
            user = self.user.to_dict()

        trending: Unset | dict[str, Any] = UNSET
        if not isinstance(self.trending, Unset):
            trending = self.trending.to_dict()

        tracker: Unset | dict[str, Any] = UNSET
        if not isinstance(self.tracker, Unset):
            tracker = self.tracker.to_dict()

        followings: Unset | dict[str, Any] = UNSET
        if not isinstance(self.followings, Unset):
            followings = self.followings.to_dict()

        federation: Unset | dict[str, Any] = UNSET
        if not isinstance(self.federation, Unset):
            federation = self.federation.to_dict()

        homepage: Unset | dict[str, Any] = UNSET
        if not isinstance(self.homepage, Unset):
            homepage = self.homepage.to_dict()

        open_telemetry: Unset | dict[str, Any] = UNSET
        if not isinstance(self.open_telemetry, Unset):
            open_telemetry = self.open_telemetry.to_dict()

        views: Unset | dict[str, Any] = UNSET
        if not isinstance(self.views, Unset):
            views = self.views.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if instance is not UNSET:
            field_dict["instance"] = instance
        if search is not UNSET:
            field_dict["search"] = search
        if plugin is not UNSET:
            field_dict["plugin"] = plugin
        if theme is not UNSET:
            field_dict["theme"] = theme
        if email is not UNSET:
            field_dict["email"] = email
        if contact_form is not UNSET:
            field_dict["contactForm"] = contact_form
        if server_version is not UNSET:
            field_dict["serverVersion"] = server_version
        if server_commit is not UNSET:
            field_dict["serverCommit"] = server_commit
        if signup is not UNSET:
            field_dict["signup"] = signup
        if transcoding is not UNSET:
            field_dict["transcoding"] = transcoding
        if import_ is not UNSET:
            field_dict["import"] = import_
        if export is not UNSET:
            field_dict["export"] = export
        if auto_blacklist is not UNSET:
            field_dict["autoBlacklist"] = auto_blacklist
        if avatar is not UNSET:
            field_dict["avatar"] = avatar
        if video is not UNSET:
            field_dict["video"] = video
        if video_caption is not UNSET:
            field_dict["videoCaption"] = video_caption
        if user is not UNSET:
            field_dict["user"] = user
        if trending is not UNSET:
            field_dict["trending"] = trending
        if tracker is not UNSET:
            field_dict["tracker"] = tracker
        if followings is not UNSET:
            field_dict["followings"] = followings
        if federation is not UNSET:
            field_dict["federation"] = federation
        if homepage is not UNSET:
            field_dict["homepage"] = homepage
        if open_telemetry is not UNSET:
            field_dict["openTelemetry"] = open_telemetry
        if views is not UNSET:
            field_dict["views"] = views

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_auto_blacklist import (
            ServerConfigAutoBlacklist,
        )
        from peertube.models.server_config_avatar import ServerConfigAvatar
        from peertube.models.server_config_contact_form import ServerConfigContactForm
        from peertube.models.server_config_email import ServerConfigEmail
        from peertube.models.server_config_export import ServerConfigExport
        from peertube.models.server_config_federation import ServerConfigFederation
        from peertube.models.server_config_followings import ServerConfigFollowings
        from peertube.models.server_config_homepage import ServerConfigHomepage
        from peertube.models.server_config_import import ServerConfigImport
        from peertube.models.server_config_instance import ServerConfigInstance
        from peertube.models.server_config_open_telemetry import (
            ServerConfigOpenTelemetry,
        )
        from peertube.models.server_config_plugin import ServerConfigPlugin
        from peertube.models.server_config_search import ServerConfigSearch
        from peertube.models.server_config_signup import ServerConfigSignup
        from peertube.models.server_config_theme import ServerConfigTheme
        from peertube.models.server_config_tracker import ServerConfigTracker
        from peertube.models.server_config_transcoding import ServerConfigTranscoding
        from peertube.models.server_config_trending import ServerConfigTrending
        from peertube.models.server_config_user import ServerConfigUser
        from peertube.models.server_config_video import ServerConfigVideo
        from peertube.models.server_config_video_caption import ServerConfigVideoCaption
        from peertube.models.server_config_views import ServerConfigViews

        d = dict(src_dict)
        _instance = d.pop("instance", UNSET)
        instance: Unset | ServerConfigInstance
        if isinstance(_instance, Unset):
            instance = UNSET
        else:
            instance = ServerConfigInstance.from_dict(_instance)

        _search = d.pop("search", UNSET)
        search: Unset | ServerConfigSearch
        if isinstance(_search, Unset):
            search = UNSET
        else:
            search = ServerConfigSearch.from_dict(_search)

        _plugin = d.pop("plugin", UNSET)
        plugin: Unset | ServerConfigPlugin
        if isinstance(_plugin, Unset):
            plugin = UNSET
        else:
            plugin = ServerConfigPlugin.from_dict(_plugin)

        _theme = d.pop("theme", UNSET)
        theme: Unset | ServerConfigTheme
        if isinstance(_theme, Unset):
            theme = UNSET
        else:
            theme = ServerConfigTheme.from_dict(_theme)

        _email = d.pop("email", UNSET)
        email: Unset | ServerConfigEmail
        if isinstance(_email, Unset):
            email = UNSET
        else:
            email = ServerConfigEmail.from_dict(_email)

        _contact_form = d.pop("contactForm", UNSET)
        contact_form: Unset | ServerConfigContactForm
        if isinstance(_contact_form, Unset):
            contact_form = UNSET
        else:
            contact_form = ServerConfigContactForm.from_dict(_contact_form)

        server_version = d.pop("serverVersion", UNSET)

        server_commit = d.pop("serverCommit", UNSET)

        _signup = d.pop("signup", UNSET)
        signup: Unset | ServerConfigSignup
        if isinstance(_signup, Unset):
            signup = UNSET
        else:
            signup = ServerConfigSignup.from_dict(_signup)

        _transcoding = d.pop("transcoding", UNSET)
        transcoding: Unset | ServerConfigTranscoding
        if isinstance(_transcoding, Unset):
            transcoding = UNSET
        else:
            transcoding = ServerConfigTranscoding.from_dict(_transcoding)

        _import_ = d.pop("import", UNSET)
        import_: Unset | ServerConfigImport
        if isinstance(_import_, Unset):
            import_ = UNSET
        else:
            import_ = ServerConfigImport.from_dict(_import_)

        _export = d.pop("export", UNSET)
        export: Unset | ServerConfigExport
        if isinstance(_export, Unset):
            export = UNSET
        else:
            export = ServerConfigExport.from_dict(_export)

        _auto_blacklist = d.pop("autoBlacklist", UNSET)
        auto_blacklist: Unset | ServerConfigAutoBlacklist
        if isinstance(_auto_blacklist, Unset):
            auto_blacklist = UNSET
        else:
            auto_blacklist = ServerConfigAutoBlacklist.from_dict(_auto_blacklist)

        _avatar = d.pop("avatar", UNSET)
        avatar: Unset | ServerConfigAvatar
        if isinstance(_avatar, Unset):
            avatar = UNSET
        else:
            avatar = ServerConfigAvatar.from_dict(_avatar)

        _video = d.pop("video", UNSET)
        video: Unset | ServerConfigVideo
        if isinstance(_video, Unset):
            video = UNSET
        else:
            video = ServerConfigVideo.from_dict(_video)

        _video_caption = d.pop("videoCaption", UNSET)
        video_caption: Unset | ServerConfigVideoCaption
        if isinstance(_video_caption, Unset):
            video_caption = UNSET
        else:
            video_caption = ServerConfigVideoCaption.from_dict(_video_caption)

        _user = d.pop("user", UNSET)
        user: Unset | ServerConfigUser
        if isinstance(_user, Unset):
            user = UNSET
        else:
            user = ServerConfigUser.from_dict(_user)

        _trending = d.pop("trending", UNSET)
        trending: Unset | ServerConfigTrending
        if isinstance(_trending, Unset):
            trending = UNSET
        else:
            trending = ServerConfigTrending.from_dict(_trending)

        _tracker = d.pop("tracker", UNSET)
        tracker: Unset | ServerConfigTracker
        if isinstance(_tracker, Unset):
            tracker = UNSET
        else:
            tracker = ServerConfigTracker.from_dict(_tracker)

        _followings = d.pop("followings", UNSET)
        followings: Unset | ServerConfigFollowings
        if isinstance(_followings, Unset):
            followings = UNSET
        else:
            followings = ServerConfigFollowings.from_dict(_followings)

        _federation = d.pop("federation", UNSET)
        federation: Unset | ServerConfigFederation
        if isinstance(_federation, Unset):
            federation = UNSET
        else:
            federation = ServerConfigFederation.from_dict(_federation)

        _homepage = d.pop("homepage", UNSET)
        homepage: Unset | ServerConfigHomepage
        if isinstance(_homepage, Unset):
            homepage = UNSET
        else:
            homepage = ServerConfigHomepage.from_dict(_homepage)

        _open_telemetry = d.pop("openTelemetry", UNSET)
        open_telemetry: Unset | ServerConfigOpenTelemetry
        if isinstance(_open_telemetry, Unset):
            open_telemetry = UNSET
        else:
            open_telemetry = ServerConfigOpenTelemetry.from_dict(_open_telemetry)

        _views = d.pop("views", UNSET)
        views: Unset | ServerConfigViews
        if isinstance(_views, Unset):
            views = UNSET
        else:
            views = ServerConfigViews.from_dict(_views)

        server_config = cls(
            instance=instance,
            search=search,
            plugin=plugin,
            theme=theme,
            email=email,
            contact_form=contact_form,
            server_version=server_version,
            server_commit=server_commit,
            signup=signup,
            transcoding=transcoding,
            import_=import_,
            export=export,
            auto_blacklist=auto_blacklist,
            avatar=avatar,
            video=video,
            video_caption=video_caption,
            user=user,
            trending=trending,
            tracker=tracker,
            followings=followings,
            federation=federation,
            homepage=homepage,
            open_telemetry=open_telemetry,
            views=views,
        )

        server_config.additional_properties = d
        return server_config

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class NSFWPolicy(str, Enum):
    """NSFWPolicy class."""

    DISPLAY = "display"
    DO_NOT_LIST = "do_not_list"
    WARN = "warn"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="ServerConfigCustomSignup")


@_attrs_define
class ServerConfigCustomSignup:
    """Attributes:
    enabled (Union[Unset, bool]):
    limit (Union[Unset, int]):
    requires_email_verification (Union[Unset, bool]):
    """

    enabled: Unset | bool = UNSET
    limit: Unset | int = UNSET
    requires_email_verification: Unset | bool = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        enabled = self.enabled

        limit = self.limit

        requires_email_verification = self.requires_email_verification

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if limit is not UNSET:
            field_dict["limit"] = limit
        if requires_email_verification is not UNSET:
            field_dict["requiresEmailVerification"] = requires_email_verification

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        enabled = d.pop("enabled", UNSET)

        limit = d.pop("limit", UNSET)

        requires_email_verification = d.pop("requiresEmailVerification", UNSET)

        server_config_custom_signup = cls(
            enabled=enabled,
            limit=limit,
            requires_email_verification=requires_email_verification,
        )

        server_config_custom_signup.additional_properties = d
        return server_config_custom_signup

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class SearchPlaylistsSearchTarget(str, Enum):
    """SearchPlaylistsSearchTarget enumeration."""

    LOCAL = "local"
    SEARCH_INDEX = "search-index"

    def __str__(self) -> str:
        """Return string representation."""

        return str(self.value)



import datetime
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="Runner")


@_attrs_define
class Runner:
    """Attributes:
    id (Union[Unset, int]):
    name (Union[Unset, str]):
    description (Union[Unset, str]):
    ip (Union[Unset, str]):
    updated_at (Union[Unset, datetime.datetime]):
    created_at (Union[Unset, datetime.datetime]):
    last_contact (Union[Unset, datetime.datetime]):
    """

    id: Unset | int = UNSET
    name: Unset | str = UNSET
    description: Unset | str = UNSET
    ip: Unset | str = UNSET
    updated_at: Unset | datetime.datetime = UNSET
    created_at: Unset | datetime.datetime = UNSET
    last_contact: Unset | datetime.datetime = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert to dictionary."""

        id = self.id

        name = self.name

        description = self.description

        ip = self.ip

        updated_at: Unset | str = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        created_at: Unset | str = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        last_contact: Unset | str = UNSET
        if not isinstance(self.last_contact, Unset):
            last_contact = self.last_contact.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if ip is not UNSET:
            field_dict["ip"] = ip
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if last_contact is not UNSET:
            field_dict["lastContact"] = last_contact

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create from dictionary."""

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        ip = d.pop("ip", UNSET)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Unset | datetime.datetime
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Unset | datetime.datetime
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _last_contact = d.pop("lastContact", UNSET)
        last_contact: Unset | datetime.datetime
        if isinstance(_last_contact, Unset):
            last_contact = UNSET
        else:
            last_contact = isoparse(_last_contact)

        runner = cls(
            id=id,
            name=name,
            description=description,
            ip=ip,
            updated_at=updated_at,
            created_at=created_at,
            last_contact=last_contact,
        )

        runner.additional_properties = d
        return runner

    @property
    def additional_keys(self) -> list[str]:
        """Get additional keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class AutomaticTagAvailableAvailableItemType(str, Enum):
    """AutomaticTagAvailableAvailableItemType enumeration."""

    CORE = "core"
    WATCHED_WORDS_LIST = "watched-words-list"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.models.runner_job_type import RunnerJobType
from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.vod_audio_merge_transcoding import VODAudioMergeTranscoding
    from peertube.models.vod_web_video_transcoding import VODWebVideoTranscoding
    from peertube.models.vodhls_transcoding import VODHLSTranscoding


T = TypeVar("T", bound="PostApiV1RunnersJobsRequestResponse200AvailableJobsItem")


@_attrs_define
class PostApiV1RunnersJobsRequestResponse200AvailableJobsItem:
    """Attributes:
    uuid (Union[Unset, UUID]):  Example: 9c9de5e8-0a1e-484a-b099-e80766180a6d.
    type_ (Union[Unset, RunnerJobType]):
    payload (Union['VODAudioMergeTranscoding', 'VODHLSTranscoding', 'VODWebVideoTranscoding', Unset]):
    """

    uuid: Unset | UUID = UNSET
    type_: Unset | RunnerJobType = UNSET
    payload: Union[
        "VODAudioMergeTranscoding", "VODHLSTranscoding", "VODWebVideoTranscoding", Unset
    ] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        uuid: Unset | str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        type_: Unset | str = UNSET
        if not isinstance(self.type_, Unset):
            type_ = self.type_.value

        payload: Unset | dict[str, Any]
        if isinstance(self.payload, Unset):
            payload = UNSET
        else:
            payload = self.payload.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if uuid is not UNSET:
            field_dict["uuid"] = uuid
        if type_ is not UNSET:
            field_dict["type"] = type_
        if payload is not UNSET:
            field_dict["payload"] = payload

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.vod_audio_merge_transcoding import VODAudioMergeTranscoding
        from peertube.models.vod_web_video_transcoding import VODWebVideoTranscoding
        from peertube.models.vodhls_transcoding import VODHLSTranscoding

        d = dict(src_dict)
        _uuid = d.pop("uuid", UNSET)
        uuid: Unset | UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = UUID(_uuid)

        _type_ = d.pop("type", UNSET)
        type_: Unset | RunnerJobType
        if isinstance(_type_, Unset):
            type_ = UNSET
        else:
            type_ = RunnerJobType(_type_)

        def _parse_payload(
            data: object,
        ) -> Union[
            "VODAudioMergeTranscoding",
            "VODHLSTranscoding",
            "VODWebVideoTranscoding",
            Unset,
        ]:
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError
                componentsschemas_runner_job_payload_vod_web_video_transcoding = (
                    VODWebVideoTranscoding.from_dict(data)
                )

                return componentsschemas_runner_job_payload_vod_web_video_transcoding
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError
                componentsschemas_runner_job_payload_vod_hls_transcoding = (
                    VODHLSTranscoding.from_dict(data)
                )

                return componentsschemas_runner_job_payload_vod_hls_transcoding
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError
            componentsschemas_runner_job_payload_vod_audio_merge_transcoding = (
                VODAudioMergeTranscoding.from_dict(data)
            )

            return componentsschemas_runner_job_payload_vod_audio_merge_transcoding

        payload = _parse_payload(d.pop("payload", UNSET))

        post_api_v1_runners_jobs_request_response_200_available_jobs_item = cls(
            uuid=uuid, type_=type_, payload=payload
        )

        post_api_v1_runners_jobs_request_response_200_available_jobs_item.additional_properties = d
        return post_api_v1_runners_jobs_request_response_200_available_jobs_item

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import cast

from peertube.api.video_playlists.playlists import sync
from peertube.types import UNSET


class TestPlaylists:
    def test_sync(self, client, httpx_mock, sample_playlist_response_data_detailed):
        # Mock the API response
        httpx_mock.add_response(
            method="GET",
            url="https://test.peertube.example/api/v1/video-playlists?count=15",
            json=sample_playlist_response_data_detailed,
            status_code=200,
        )

        # Call the sync function
        result = sync(client=client)

        # Assert the result
        assert result is not None
        assert result.total == 2
        assert result.data is not UNSET
        data = cast("list", result.data)
        assert len(data) == 2
        assert data[0].id == 1
        assert data[0].display_name == "My Playlist 1"
        assert data[1].id == 2
        assert data[1].display_name == "My Playlist 2"



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

if TYPE_CHECKING:
    from peertube.models.block_status_accounts_additional_property import (
        BlockStatusAccountsAdditionalProperty,
    )


T = TypeVar("T", bound="BlockStatusAccounts")


@_attrs_define
class BlockStatusAccounts:
    """Block status accounts data model."""

    additional_properties: dict[str, "BlockStatusAccountsAdditionalProperty"] = (
        _attrs_field(init=False, factory=dict)
    )

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.to_dict()

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.block_status_accounts_additional_property import (
            BlockStatusAccountsAdditionalProperty,
        )

        d = dict(src_dict)
        block_status_accounts = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = BlockStatusAccountsAdditionalProperty.from_dict(
                prop_dict
            )

            additional_properties[prop_name] = additional_property

        block_status_accounts.additional_properties = additional_properties
        return block_status_accounts

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> "BlockStatusAccountsAdditionalProperty":
        return self.additional_properties[key]

    def __setitem__(
        self, key: str, value: "BlockStatusAccountsAdditionalProperty"
    ) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

T = TypeVar("T", bound="Storyboard")


@_attrs_define
class Storyboard:
    """Attributes:
    storyboard_path (Union[Unset, str]):
    total_height (Union[Unset, int]):
    total_width (Union[Unset, int]):
    sprite_height (Union[Unset, int]):
    sprite_width (Union[Unset, int]):
    sprite_duration (Union[Unset, int]):
    """

    storyboard_path: Unset | str = UNSET
    total_height: Unset | int = UNSET
    total_width: Unset | int = UNSET
    sprite_height: Unset | int = UNSET
    sprite_width: Unset | int = UNSET
    sprite_duration: Unset | int = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        storyboard_path = self.storyboard_path

        total_height = self.total_height

        total_width = self.total_width

        sprite_height = self.sprite_height

        sprite_width = self.sprite_width

        sprite_duration = self.sprite_duration

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if storyboard_path is not UNSET:
            field_dict["storyboardPath"] = storyboard_path
        if total_height is not UNSET:
            field_dict["totalHeight"] = total_height
        if total_width is not UNSET:
            field_dict["totalWidth"] = total_width
        if sprite_height is not UNSET:
            field_dict["spriteHeight"] = sprite_height
        if sprite_width is not UNSET:
            field_dict["spriteWidth"] = sprite_width
        if sprite_duration is not UNSET:
            field_dict["spriteDuration"] = sprite_duration

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        d = dict(src_dict)
        storyboard_path = d.pop("storyboardPath", UNSET)

        total_height = d.pop("totalHeight", UNSET)

        total_width = d.pop("totalWidth", UNSET)

        sprite_height = d.pop("spriteHeight", UNSET)

        sprite_width = d.pop("spriteWidth", UNSET)

        sprite_duration = d.pop("spriteDuration", UNSET)

        storyboard = cls(
            storyboard_path=storyboard_path,
            total_height=total_height,
            total_width=total_width,
            sprite_height=sprite_height,
            sprite_width=sprite_width,
            sprite_duration=sprite_duration,
        )

        storyboard.additional_properties = d
        return storyboard

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any

import httpx

from peertube.api.shared_utils import build_response, parse_response
from peertube.client import AuthenticatedClient, Client
from peertube.models.abuse_state_set import AbuseStateSet
from peertube.models.get_my_abuses_sort import GetMyAbusesSort
from peertube.types import UNSET, Response, Unset


def _get_kwargs(
    *,
    id: Unset | int = UNSET,
    state: Unset | AbuseStateSet = UNSET,
    sort: Unset | GetMyAbusesSort = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
) -> dict[str, Any]:
    params: dict[str, Any] = {}

    params["id"] = id
    json_state: Unset | int = UNSET
    if not isinstance(state, Unset):
        json_state = state.value

    params["state"] = json_state
    json_sort: Unset | str = UNSET
    if not isinstance(sort, Unset):
        json_sort = sort.value

    params["sort"] = json_sort

    params["start"] = start

    params["count"] = count
    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/api/v1/users/me/abuses",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    return parse_response(client=client, response=response)


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(
    *,
    client: AuthenticatedClient,
    id: Unset | int = UNSET,
    state: Unset | AbuseStateSet = UNSET,
    sort: Unset | GetMyAbusesSort = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
) -> Response[Any]:
    """List my abuses


    Args:
        id (Union[Unset, int]): Unique identifier for the entity.
        state (Union[Unset, AbuseStateSet]): The abuse state (Pending=`1`, Rejected=`2`, Accepted=`3`)
        sort (Union[Unset, GetMyAbusesSort]): Sorting criteria for results.
        start (Union[Unset, int]): Starting index for pagination.
        client: Authenticated HTTP client for API requests.
        count (Union[Unset, int]):  Default: 15.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(id=id, state=state, sort=sort, start=start, count=count)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    id: Unset | int = UNSET,
    state: Unset | AbuseStateSet = UNSET,
    sort: Unset | GetMyAbusesSort = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
) -> Any | None:
    """List my abuses


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(
        client=client, id=id, state=state, sort=sort, start=start, count=count
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    id: Unset | int = UNSET,
    state: Unset | AbuseStateSet = UNSET,
    sort: Unset | GetMyAbusesSort = UNSET,
    start: Unset | int = UNSET,
    count: Unset | int = 15,
) -> Response[Any]:
    """List my abuses


    Args:
        id (Union[Unset, int]): Unique identifier for the entity.
        state (Union[Unset, AbuseStateSet]): The abuse state (Pending=`1`, Rejected=`2`, Accepted=`3`)
        sort (Union[Unset, GetMyAbusesSort]): Sorting criteria for results.
        start (Union[Unset, int]): Starting index for pagination.
        client: Authenticated HTTP client for API requests.
        count (Union[Unset, int]):  Default: 15.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(id=id, state=state, sort=sort, start=start, count=count)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from enum import IntEnum


class VideoStateConstantId(IntEnum):
    """VideoStateConstantId class."""

    VALUE_1 = 1
    VALUE_2 = 2
    VALUE_3 = 3
    VALUE_4 = 4
    VALUE_5 = 5
    VALUE_6 = 6
    VALUE_7 = 7
    VALUE_8 = 8
    VALUE_9 = 9

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Self

from peertube.types import UNSET, Unset

if TYPE_CHECKING:
    from peertube.models.server_config_import_users import ServerConfigImportUsers
    from peertube.models.server_config_import_video_channel_synchronization import (
        ServerConfigImportVideoChannelSynchronization,
    )
    from peertube.models.server_config_import_videos import ServerConfigImportVideos


T = TypeVar("T", bound="ServerConfigImport")


@_attrs_define
class ServerConfigImport:
    """Attributes:
    videos (Union[Unset, ServerConfigImportVideos]):
    video_channel_synchronization (Union[Unset, ServerConfigImportVideoChannelSynchronization]):
    users (Union[Unset, ServerConfigImportUsers]):
    """

    videos: Union[Unset, "ServerConfigImportVideos"] = UNSET
    video_channel_synchronization: Union[
        Unset, "ServerConfigImportVideoChannelSynchronization"
    ] = UNSET
    users: Union[Unset, "ServerConfigImportUsers"] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        """Convert instance to dictionary."""

        videos: Unset | dict[str, Any] = UNSET
        if not isinstance(self.videos, Unset):
            videos = self.videos.to_dict()

        video_channel_synchronization: Unset | dict[str, Any] = UNSET
        if not isinstance(self.video_channel_synchronization, Unset):
            video_channel_synchronization = self.video_channel_synchronization.to_dict()

        users: Unset | dict[str, Any] = UNSET
        if not isinstance(self.users, Unset):
            users = self.users.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if videos is not UNSET:
            field_dict["videos"] = videos
        if video_channel_synchronization is not UNSET:
            field_dict["videoChannelSynchronization"] = video_channel_synchronization
        if users is not UNSET:
            field_dict["users"] = users

        return field_dict

    @classmethod
    def from_dict(cls, src_dict: Mapping[str, Any]) -> Self:
        """Create instance from dictionary."""

        from peertube.models.server_config_import_users import ServerConfigImportUsers
        from peertube.models.server_config_import_video_channel_synchronization import (
            ServerConfigImportVideoChannelSynchronization,
        )
        from peertube.models.server_config_import_videos import ServerConfigImportVideos

        d = dict(src_dict)
        _videos = d.pop("videos", UNSET)
        videos: Unset | ServerConfigImportVideos
        if isinstance(_videos, Unset):
            videos = UNSET
        else:
            videos = ServerConfigImportVideos.from_dict(_videos)

        _video_channel_synchronization = d.pop("videoChannelSynchronization", UNSET)
        video_channel_synchronization: (
            Unset | ServerConfigImportVideoChannelSynchronization
        )
        if isinstance(_video_channel_synchronization, Unset):
            video_channel_synchronization = UNSET
        else:
            video_channel_synchronization = (
                ServerConfigImportVideoChannelSynchronization.from_dict(
                    _video_channel_synchronization
                )
            )

        _users = d.pop("users", UNSET)
        users: Unset | ServerConfigImportUsers
        if isinstance(_users, Unset):
            users = UNSET
        else:
            users = ServerConfigImportUsers.from_dict(_users)

        server_config_import = cls(
            videos=videos,
            video_channel_synchronization=video_channel_synchronization,
            users=users,
        )

        server_config_import.additional_properties = d
        return server_config_import

    @property
    def additional_keys(self) -> list[str]:
        """Get additional property keys."""

        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Tests for del_mirrored_video function."""

from peertube.api.video_mirroring.del_mirrored_video import sync


def test_del_mirrored_video_success(httpx_mock, auth_client):
    """Test successful deletion of mirrored video."""
    # Mock HTTP response
    httpx_mock.add_response(
        method="DELETE",
        url="https://test.peertube.example/api/v1/server/redundancy/videos/test-redundancy-id",
        status_code=204,
    )

    # Test the function
    result = sync(redundancy_id="test-redundancy-id", client=auth_client)

    assert result is None



from typing import Any

import httpx

from peertube import errors
from peertube.api.shared_utils import build_response
from peertube.client import AuthenticatedClient, Client
from peertube.types import Response


def _get_kwargs(handle: str) -> dict[str, Any]:
    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": f"/api/v1/server/followers/{handle}",
    }

    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | None:
    if response.status_code == 204:
        return None

    if response.status_code == 404:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any]:
    return build_response(client=client, response=response)


def sync_detailed(handle: str, *, client: AuthenticatedClient) -> Response[Any]:
    """Remove or reject a follower to your server


    Args:
        handle (str): Parameter for handle.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(handle=handle)

    response = client.get_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


def sync(handle: str, *, client: AuthenticatedClient) -> Any | None:
    """Remove or reject a follower to your server


    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any
    """

    return sync_detailed(handle=handle, client=client).parsed


async def asyncio_detailed(
    handle: str, *, client: AuthenticatedClient
) -> Response[Any]:
    """Remove or reject a follower to your server


    Args:
        handle (str): Parameter for handle.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(handle=handle)

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)
